#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module P2p
            class AccountBalance < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'af8a1009-aa52-412b-8323-5a60d009eb53' => OperationConfig.new("/send/v1/partners/{partnerId}/non-card-tokens/{nonCardToken}/account-balance", "query", [], []),
                    '80e690b7-eb43-428d-b24d-7e330c460996' => OperationConfig.new("/send/v1/partners/{partnerId}/account-balances", "query", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public







                def self.accountBalanceForSpecificAccount(criteria)
                    #
                    #Query objects of type AccountBalance by id and optional criteria
                    #@param [Dict] criteria
                    #@return [AccountBalance] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("af8a1009-aa52-412b-8323-5a60d009eb53",AccountBalance.new(criteria))
                end







                def self.accountBalancesForSpecificPartner(criteria)
                    #
                    #Query objects of type AccountBalance by id and optional criteria
                    #@param [Dict] criteria
                    #@return [AccountBalance] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("80e690b7-eb43-428d-b24d-7e330c460996",AccountBalance.new(criteria))
                end


            end
        end
    end
end







