#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module P2p
            class PaymentTransfer < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'bf833b90-9bfb-4bb6-98f9-4f5c012c7e51' => OperationConfig.new("/send/v1/partners/{partnerId}/transfers/payment", "create", [], []),
                    'c1a1e381-db60-41c0-a5e7-183d227fb21b' => OperationConfig.new("/send/v1/partners/{partnerId}/transfers/{transferId}", "read", [], []),
                    'ff62e58b-1971-4a65-b8e8-d155f5b5f015' => OperationConfig.new("/send/v1/partners/{partnerId}/transfers", "query", [], ["ref"]),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.create(mapObj)
                    #
                    #Creates object of type PaymentTransfer
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [PaymentTransfer] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("bf833b90-9bfb-4bb6-98f9-4f5c012c7e51", PaymentTransfer.new(mapObj))
                end











                def self.readByID(id, criteria = nil)
                    #
                    #Returns objects of type PaymentTransfer by id and optional criteria
                    #@param [String] id
                    #@param [Dict] criteria
                    #@return [PaymentTransfer] object representing the response
                    #@raise [APIException] an exception from the response status

                    mapObj = PaymentTransfer.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !criteria.nil?
                        if criteria.instance_of? RequestMap
                          mapObj.setAll(criteria.getObject())
                        else
                          mapObj.setAll(criteria)
                        end
                    end

                    return self.execute("c1a1e381-db60-41c0-a5e7-183d227fb21b",PaymentTransfer.new(mapObj))
                end








                def self.readByReference(criteria)
                    #
                    #Query objects of type PaymentTransfer by id and optional criteria
                    #@param [Dict] criteria
                    #@return [PaymentTransfer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("ff62e58b-1971-4a65-b8e8-d155f5b5f015",PaymentTransfer.new(criteria))
                end


            end
        end
    end
end







